BasicThreatBar = LibStub("AceAddon-3.0"):NewAddon("BasicThreatBar", "AceConsole-3.0", "AceEvent-3.0")
local self = BasicThreatBar


local LSM = LibStub("LibSharedMedia-3.0")

local threatbar = CreateFrame("StatusBar", "ThreatBar", UIParent)

threatbar:EnableMouse(true)
threatbar:SetMovable(true)
threatbar:SetResizable(true)
threatbar:SetClampedToScreen( true )
threatbar:SetMaxResize(500,125);
threatbar:SetMinResize(125,16);
threatbar:RegisterForDrag("LeftButton");

local function GetPosition()
local point, _, relativePoint, xOfs, yOfs = threatbar:GetPoint()
local height = threatbar:GetHeight()
local width = threatbar:GetWidth()
	self.db.profile.point = point
	self.db.profile.relativePoint = relativePoint
	self.db.profile.xOfs = xOfs
	self.db.profile.yOfs = yOfs
	self.db.profile.height = height
	self.db.profile.width = width
end

threatbar:SetScript("OnDragStart", function(s) 
	if not UnitAffectingCombat("player") then
		if IsAltKeyDown() then s:StartMoving() 
		elseif IsShiftKeyDown() then s:StartSizing()
		end 
	end
end)
threatbar:SetScript("OnDragStop", function(s) 
s:StopMovingOrSizing()
GetPosition()
end)
threatbar:SetScript("OnEnter", function(s) 
	if not UnitAffectingCombat("player") then
		GameTooltip:SetOwner(s, "ANCHOR_TOP")
        GameTooltip:AddLine("Basic Threat Bar", 0, 1, 0.5, 1, 1, 1)
        GameTooltip:AddLine("Hold down SHIFT to resize.", 1, 1, 1, 1, 1, 1)
		GameTooltip:AddLine("Hold down ALT to move.", 1, 1, 1, 1, 1, 1)
        GameTooltip:AddLine("Type /btb hide to hide bar out of combat.", 1, 1, 1, 1, 1, 1)
		GameTooltip:AddLine("Type /btb show to leave visible.", 1, 1, 1, 1, 1, 1)
		GameTooltip:AddLine("Type /btb to change settings.", 1, 1, 1, 1, 1, 1)
		GameTooltip:Show()
	end
end)
threatbar:SetScript("OnLeave", function(s)
GameTooltip:Hide()
end)

threatbar:SetMinMaxValues(0, 100)
threatbar:SetValue(0)

local font1 = threatbar:CreateFontString("UnitName", "ARTWORK", "GameFontWhite")
font1:SetPoint("TOP", threatbar, "TOP", 0, 15)

local font2 = threatbar:CreateFontString("Percent", "OVERLAY", "GameFontWhite")
font2:SetPoint("CENTER", threatbar, "CENTER", 0, 0)

--local icon = threatbar:CreateTexture("Icon", "OVERLAY")
--icon:SetTexture("Interface\\LFGFrame\\UI-LFG-ICON-PORTRAITROLES")
--icon:SetTexCoord(GetTexCoordsForRoleSmallCircle("TANK"))
--icon:SetPoint("TOPLEFT", threatbar, "TOPLEFT", 0, 15)
--icon:SetHeight(14)
--icon:SetWidth(14)
--icon:Hide()

local function SetFont()
local flags = {}
    if self.db.profile.outline then
        tinsert(flags, "OUTLINE")
    end
    if self.db.profile.monochrome then
        tinsert(flags, "MONOCHROME")
    end
    if self.db.profile.thickoutline then
        tinsert(flags, "THICKOUTLINE")
    end
font1:SetFont(LSM:Fetch("font", self.db.profile.font), self.db.profile.fontsize, table.concat(flags, ","))
font2:SetFont(LSM:Fetch("font", self.db.profile.font), self.db.profile.fontsize, table.concat(flags, ","))
end

function BasicThreatBar:RefreshConfig()
	threatbar:SetStatusBarTexture(LSM:Fetch("statusbar", self.db.profile.texture))
	threatbar:SetBackdrop({ 
	bgFile = LSM:Fetch("statusbar", self.db.profile.texture),
	insets = {left = 0, right = 0, top = 0, bottom = 0}
})
	threatbar:SetBackdropColor(0, 0, 0, .5)
	
	threatbar:ClearAllPoints()
	threatbar:SetHeight(self.db.profile.height)
	threatbar:SetWidth(self.db.profile.width)
	threatbar:SetPoint(self.db.profile.point, UIParent, self.db.profile.relativePoint, self.db.profile.xOfs, self.db.profile.yOfs)
	
	SetFont()
	
	font2:SetTextColor(self.db.profile.red, self.db.profile.green, self.db.profile.blue, self.db.profile.alpha)
		
	if not self.db.profile.hidden then
		threatbar:Show()
	else
		threatbar:Hide()
	end

end

local defaults = {
  profile = {
    hidden = false, 
	font = "Friz Quadrata TT",
	texture = "Blizzard", 
	fontsize = 12, 
	point = "CENTER", 
	relativePoint = "CENTER", 
	xOfs = 0, 
	yOfs = 0, 
	height = 30, 
	width = 200, 
	outline = false, 
	monochrome = false, 
	thickoutline = false, 
	red = 1, 
	green = 1, 
	blue = 1, 
	alpha = 1,
  }
}

local options = {
    name = "BasicThreatBar",
    type = 'group',
	args = {
		general = {
			order = 1,
			name = "General",
			type = 'group',
			args = {
				Hide = {
				name = "Hide bar",
				desc = 'Hide the bar when not in combat',
				type = 'toggle',
				order = 1,
				set = function(info, key)
					self.db.profile.hidden = key
					if self.db.profile.hidden then
					threatbar:Hide()
					else
					threatbar:Show()
					end
				end,
				get = function(info)
					return self.db.profile.hidden
				end,
				},
		
		
	
		
		Font = {
		name = "Font",
		type = 'group',
		inline = true,
		order = 2,
		args = {
			Fonts = {
				type = 'select',
				name = 'Fonts',
				desc = 'Change the Font',
				order = 1,
				set = function(info,key)
				self.db.profile.font = key -- saves our new selection the the current one
				SetFont()
				end,
				get = function()
				return self.db.profile.font -- variable that is my current selection
				end,
				dialogControl = "LSM30_Font",
				values = LSM:HashTable("font"),
			},
			fontSize = {
				type = 'range',
				name = 'Font size',
				min = 8,
				max = 32,
				step = 1,
				order = 10,
				set = function(info,key)
				self.db.profile.fontsize = key -- saves our new selection the the current one
				SetFont()
				end,
				get = function()
				return self.db.profile.fontsize -- variable that is my current selection
				end,
			},
			font_outline = {
        		name = "Outline",
        		desc = "Adds outline to the font",
        		type = "toggle",
        		order = 120,
        		set = function(info, key)
					self.db.profile.outline = key
					SetFont()
        		end,
                get = function(info)
                return self.db.profile.outline
                end,
        	},
			font_monochrome = {
        		name = "Monochrome",
        		desc = "Sets font to monochrome",
        		type = "toggle",
        		order = 100,
        		set = function(info, key)
        			self.db.profile.monochrome = key
					SetFont()
        		end,
                get = function(info)
                return self.db.profile.monochrome
                end,
        	},
        	font_thickoutline = {
        		name = "Thick Outline",
        		desc = "Adds a thick black outline to the font",
        		type = "toggle",
        		order = 110,
        		set = function(info, key)
        		self.db.profile.thickoutline = key
        		SetFont()
        		end,
                get = function(info)
                return self.db.profile.thickoutline
                end,
        	},
			font_color = {
        		name = "Color",
        		desc = "Changes the color of the threat text",
        		type = "color",
        		order = 90,
        		set = function(info, r, g, b ,a)
        		self.db.profile.red, self.db.profile.green, self.db.profile.blue, self.db.profile.alpha = r, g, b, a
        		font2:SetTextColor(self.db.profile.red, self.db.profile.green, self.db.profile.blue, self.db.profile.alpha)
        		end,
                get = function(info)
                return self.db.profile.red, self.db.profile.green, self.db.profile.blue, self.db.profile.alpha
                end,
        	},
		},
	},
	Textures = {
	name = "Texture",
    type = 'group',
	inline = true,
	order = 2,
    args = {
		Textures = {
            type = 'select',
            name = 'Textures',
            desc = 'Change the bar texture',
            set = function(info,key)
			self.db.profile.texture = key -- saves our new selection the the current one
			threatbar:SetStatusBarTexture(LSM:Fetch("statusbar", self.db.profile.texture))
			threatbar:SetBackdrop({ 
			bgFile = LSM:Fetch("statusbar", self.db.profile.texture),
			insets = {left = 0, right = 0, top = 0, bottom = 0}
			})
			threatbar:SetBackdropColor(0, 0, 0, .5)
			end,
            get = function()
			return self.db.profile.texture -- variable that is my current selection
			end,
			dialogControl = "LSM30_Statusbar",
			values = LSM:HashTable("statusbar"),
				},
			},
		},
	},
		},
		},
}

function BasicThreatBar:OnInitialize()

	self.db = LibStub("AceDB-3.0"):New("BasicThreatBarDB", defaults)
	
	options.args.profile = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db)
	local AceConfig = LibStub("AceConfig-3.0")
	AceConfig:RegisterOptionsTable("BasicThreatBar", options, nil)
	self.optionsFrame = {}
	local AceConfigDialog = LibStub("AceConfigDialog-3.0")
	self.optionsFrame.Main = AceConfigDialog:AddToBlizOptions("BasicThreatBar", "BasicThreatBar", nil, "general")
	
	AceConfigDialog:AddToBlizOptions(
	    "BasicThreatBar", options.args.profile.name, "BasicThreatBar", "profile")
	
	self.db.RegisterCallback(self, "OnProfileChanged", "RefreshConfig")
	self.db.RegisterCallback(self, "OnProfileCopied", "RefreshConfig")
	self.db.RegisterCallback(self, "OnProfileReset", "RefreshConfig")
	
end

function BasicThreatBar:OnEnable()
GetPosition()
BasicThreatBar:RefreshConfig()
BasicThreatBar:RegisterEvent("UNIT_THREAT_SITUATION_UPDATE")
BasicThreatBar:RegisterEvent("UNIT_THREAT_LIST_UPDATE")
BasicThreatBar:RegisterEvent("PLAYER_TARGET_CHANGED")
BasicThreatBar:RegisterEvent("PARTY_MEMBERS_CHANGED")
--BasicThreatBar:RegisterEvent("PLAYER_LOGIN")
BasicThreatBar:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
end

BasicThreatBar:RegisterChatCommand("btb", "Slashhandler")

function BasicThreatBar:Slashhandler(input)
	if (input=="show") then
		threatbar:Show()
		self.db.profile.hidden = nil
	elseif (input=="hide") then
		threatbar:Hide()
		self.db.profile.hidden = true
	elseif (input=="" or input =="help") then
		InterfaceOptionsFrame_OpenToCategory("BasicThreatBar")
	end
end


local fademiActive = fademiActive -- set values
local tempthreat = {}--tempthreat -- set values
local currenttarget = currenttarget -- set values


local function GetLastThreat(mobId)
local targetGUID = UnitGUID("target")
if UnitCanAttack("player", mobId) then
	tempthreat[UnitGUID(mobId)] = select(5, UnitDetailedThreatSituation("player", mobId))
	if targetGUID == UnitGUID(mobId) then
		currenttarget = tempthreat[UnitGUID(mobId)]
	end
end
end

local function StoreThreat()
	if GetNumPartyMembers() > 0 or GetNumRaidMembers() > 0 then
		if GetNumRaidMembers() > 0 then
			for i = 1, GetNumRaidMembers() do
				GetLastThreat("raidtarget"..i)
				GetLastThreat("raidpettarget"..i)
				GetLastThreat("raidtargettarget"..i)
				GetLastThreat("raidpettargettarget"..i)
			end
		else
			for i = 1, GetNumPartyMembers() do
				GetLastThreat("partytarget"..i)
				GetLastThreat("partypettarget"..i)
				GetLastThreat("partytargettarget"..i)
				GetLastThreat("partypettargettarget"..i)
			end
		end

	end
	GetLastThreat("target")
	GetLastThreat("pettarget")
	GetLastThreat("targettarget")
	GetLastThreat("focus")
	GetLastThreat("focustarget")
	GetLastThreat("mouseover")
	GetLastThreat("mouseovertarget")

end

local function GetThreat(unitId, mobId)
	local _, _, threatpct, _, _ = UnitDetailedThreatSituation(unitId, mobId)
	if not threatpct then threatpct = 0 end
	return floor(threatpct)
end

local function GetThreatStatus(unitId, mobId)
	local _,status,_,_, _ = UnitDetailedThreatSituation(unitId, mobId)
	return status
end

local function GetTank(unitId, mobId)
	local isTanking,_,_,_, _ = UnitDetailedThreatSituation(unitId, mobId)
	if not isTanking then isTanking = 0 end
	return isTanking
end

local function GetThreatValue(unitId, mobId)
	local _, _, _, _, threatvalue = UnitDetailedThreatSituation(unitId, mobId)
	if not threatvalue then threatvalue = 0 end
	return threatvalue
end

local function GetClassColor(unit)
	local unitClass, englishClass = UnitClass(unit)
	local classColor = RAID_CLASS_COLORS[englishClass] 
	return classColor.r, classColor.g, classColor.b
end

local function UpdateDisplay()
	font1:SetText("")
	font2:SetText("")
	--icon:Hide()
	threatbar:SetValue(0)
	threatbar:SetBackdropColor(0, 0, 0, .5)
	local status = nil
	local highUnit = ""
	local unitThreat = 0
	local highThreat = 0
	local tankName = nil
	local unitThreatValue = 0
	local playerThreatValue = 0
	local partynum = GetNumPartyMembers()
	local raidnum = GetNumRaidMembers()
	
	if self.db.profile.hidden == true  and not status then -- hide frame
		threatbar:Hide()
	end
	if (partynum == 0 and raidnum == 0) and UnitCanAttack("player", "target") and not(UnitIsDead("target") or UnitIsFriend("player", "target") or UnitPlayerControlled("target")) -- Solo Target
	then			
		status = GetThreatStatus("player", "target")
		threatpct = GetThreat("player", "target")
		playerThreatValue = GetThreatValue("player", "target")
		if HasPetUI() then
			unitThreatValue = GetThreatValue("pet", "target")
			highThreat = GetThreat("pet", "target")
			highUnit = UnitName("pet")
			highUnitColorR, highUnitColorG, highUnitColorB = GetClassColor("pet")
			unitTanking = GetTank("pet", "target")
			if unitTanking == 1 then
				unitTankingColorR, unitTankingColorG, unitTankingColorB = GetClassColor("pet")
				tankName = UnitName("pet")
			end
		end
	elseif (partynum == 0 and raidnum == 0) and UnitCanAttack("player", "targettarget") and not (UnitCanAttack("player", "target") or UnitIsDead("targettarget") or UnitIsFriend("player", "targettarget") or UnitPlayerControlled("targettarget")) -- Solo Target of Target
	then
		status = GetThreatStatus("player", "targettarget")
		threatpct = GetThreat("player", "targettarget")
		playerThreatValue = GetThreatValue("player", "targettarget")
		if HasPetUI() then
			unitThreatValue = GetThreatValue("pet", "targettarget")
			highThreat = GetThreat("pet", "targettarget")
			highUnit = UnitName("pet")
			highUnitColorR, highUnitColorG, highUnitColorB = GetClassColor("pet")
			unitTanking = GetTank("pet", "targettarget")
			if unitTanking == 1 then
				unitTankingColorR, unitTankingColorG, unitTankingColorB = GetClassColor("pet")
				tankName = UnitName("pet")
			end
		end
	elseif (raidnum > 0) and UnitCanAttack("player", "target") and not (UnitIsDead("target") or UnitIsFriend("player", "target") or UnitPlayerControlled("target")) --Raid Target
	then 
		status = GetThreatStatus("player", "target")
		threatpct = GetThreat("player", "target")
		playerThreatValue = GetThreatValue("player", "target")
		for i = 1, (raidnum -1) do
			unitThreat = GetThreat("raid"..i, "target") 	
				if unitThreat > highThreat then 
					highThreat = unitThreat	
					highUnit = UnitName("raid"..i)
					highUnitColorR, highUnitColorG, highUnitColorB = GetClassColor("raid"..i)
					unitThreatValue = GetThreatValue("raid"..i, "target")
				end
			unitThreat = GetThreat("raidpet"..i, "target")	
				if unitThreat > highThreat then 
					highThreat = unitThreat	
					highUnit = UnitName("raidpet"..i)
					highUnitColorR, highUnitColorG, highUnitColorB = GetClassColor("pet")
					unitThreatValue = GetThreatValue("raidpet"..i, "target")
				end
			unitThreat = GetThreat("pet", "target")
				if unitThreat > highThreat then
					highThreat = unitThreat
					highUnit = UnitName("pet")
					highUnitColorR, highUnitColorG, highUnitColorB = GetClassColor("pet")
					unitThreatValue = GetThreatValue("pet", "target")
				end
			unitTanking = GetTank("raid"..i, "target")
			if unitTanking == 1 then
				unitTankingColorR, unitTankingColorG, unitTankingColorB = GetClassColor("raid"..i)
				tankName = UnitName("raid"..i)
			end
			unitTanking = GetTank("raidpet"..i, "target")
			if unitTanking == 1 then
				unitTankingColorR, unitTankingColorG, unitTankingColorB = GetClassColor("raidpet"..i)
				tankName = UnitName("raidpet"..i)
			end
			unitTanking = GetTank("pet", "target")
			if unitTanking == 1 then
				unitTankingColorR, unitTankingColorG, unitTankingColorB = GetClassColor("pet")
				tankName = UnitName("pet")
			end
		end
	elseif (raidnum > 0) and UnitCanAttack("player", "targettarget") and not (UnitCanAttack("player", "target") or UnitIsDead("targettarget") or UnitIsFriend("player", "targettarget") or UnitPlayerControlled("targettarget")) --Raid Target of Target
	then
		status = GetThreatStatus("player", "targettarget")
		threatpct = GetThreat("player", "targettarget")	
		playerThreatValue = GetThreatValue("player", "targettarget")
		for i = 1, (raidnum -1) do
			unitThreat = GetThreat("raid"..i, "targettarget") 	
				if unitThreat > highThreat then 
					highThreat = unitThreat	
					highUnit = UnitName("raid"..i)
					highUnitColorR, highUnitColorG, highUnitColorB = GetClassColor("raid"..i)
					unitThreatValue = GetThreatValue("raid"..i, "targettarget")
				end
			unitThreat = GetThreat("raidpet"..i, "targettarget")	
				if unitThreat > highThreat then 
					highThreat = unitThreat	
					highUnit = UnitName("raidpet"..i)
					highUnitColorR, highUnitColorG, highUnitColorB = GetClassColor("pet")
					unitThreatValue = GetThreatValue("raidpet"..i, "targettarget")
				end
			unitThreat = GetThreat("pet", "targettarget")
				if unitThreat > highThreat then
					highThreat = unitThreat
					highUnit = UnitName("pet")
					highUnitColorR, highUnitColorG, highUnitColorB = GetClassColor("pet")
					unitThreatValue = GetThreatValue("pet", "targettarget")
				end
			unitTanking = GetTank("raid"..i, "targettarget")
			if unitTanking == 1 then
				unitTankingColorR, unitTankingColorG, unitTankingColorB = GetClassColor("raid"..i)
				tankName = UnitName("raid"..i)
			end
			unitTanking = GetTank("raidpet"..i, "targettarget")
			if unitTanking == 1 then
				unitTankingColorR, unitTankingColorG, unitTankingColorB = GetClassColor("raidpet"..i)
				tankName = UnitName("raidpet"..i)
			end
			unitTanking = GetTank("pet", "targettarget")
			if unitTanking == 1 then
				unitTankingColorR, unitTankingColorG, unitTankingColorB = GetClassColor("pet")
				tankName = UnitName("pet")
			end
		end
	elseif (partynum > 0) and UnitCanAttack("player", "target") and not (UnitIsDead("target") or UnitIsFriend("player", "target") or UnitPlayerControlled("target")) -- Party Target
	then 
		status = GetThreatStatus("player", "target")
		threatpct = GetThreat("player", "target")
		playerThreatValue = GetThreatValue("player", "target")
		for i = 1, partynum do
			unitThreat = GetThreat("party"..i, "target") 	
				if unitThreat > highThreat then 
					highThreat = unitThreat	
					highUnit = UnitName("party"..i)
					highUnitColorR, highUnitColorG, highUnitColorB = GetClassColor("party"..i)
					unitThreatValue = GetThreatValue("party"..i, "target")
				end
			unitThreat = GetThreat("partypet"..i, "target")	
				if unitThreat > highThreat then 
					highThreat = unitThreat	
					highUnit = UnitName("partypet"..i)
					highUnitColorR, highUnitColorG, highUnitColorB = GetClassColor("partypet"..i)
					unitThreatValue = GetThreatValue("partypet"..i, "target")
				end
			unitThreat = GetThreat("pet", "target")
				if unitThreat > highThreat then
					highThreat = unitThreat
					highUnit = UnitName("pet")
					highUnitColorR, highUnitColorG, highUnitColorB = GetClassColor("pet")
					unitThreatValue = GetThreatValue("pet", "target")
				end
			unitTanking = GetTank("party"..i, "target")
			if unitTanking == 1 then
				unitTankingColorR, unitTankingColorG, unitTankingColorB = GetClassColor("party"..i)
				tankName = UnitName("party"..i)
			end
			unitTanking = GetTank("partypet"..i, "target")
			if unitTanking == 1 then
				unitTankingColorR, unitTankingColorG, unitTankingColorB = GetClassColor("partypet"..i)
				tankName = UnitName("partypet"..i)
			end
			unitTanking = GetTank("pet", "target")
			if unitTanking == 1 then
				unitTankingColorR, unitTankingColorG, unitTankingColorB = GetClassColor("pet")
				tankName = UnitName("pet")
			end
		end
	elseif (partynum > 0) and UnitCanAttack("player", "targettarget") and not (UnitCanAttack("player", "target") or UnitIsDead("targettarget") or UnitIsFriend("player", "targettarget") or UnitPlayerControlled("targettarget")) --Party Target of Target
	then
		status = GetThreatStatus("player", "targettarget")
		threatpct = GetThreat("player", "targettarget")
		playerThreatValue = GetThreatValue("player", "targettarget")
		for i = 1, partynum do
			unitThreat = GetThreat("party"..i, "targettarget") 	
				if unitThreat > highThreat then 
					highThreat = unitThreat	
					highUnit = UnitName("party"..i)
					highUnitColorR, highUnitColorG, highUnitColorB = GetClassColor("party"..i)
					unitThreatValue = GetThreatValue("party"..i, "targettarget")
				end
			unitThreat = GetThreat("partypet"..i, "targettarget")	
				if unitThreat > highThreat then 
					highThreat = unitThreat	
					highUnit = UnitName("partypet"..i)
					highUnitColorR, highUnitColorG, highUnitColorB = GetClassColor("partypet"..i)
					unitThreatValue = GetThreatValue("partypet"..i, "targettarget")
				end
			unitThreat = GetThreat("pet", "targettarget")
				if unitThreat > highThreat then
					highThreat = unitThreat
					highUnit = UnitName("pet")
					highUnitColorR, highUnitColorG, highUnitColorB = GetClassColor("pet")
					unitThreatValue = GetThreatValue("pet", "targettarget")
				end
			unitTanking = GetTank("party"..i, "targettarget")
			if unitTanking == 1 then
				unitTankingColorR, unitTankingColorG, unitTankingColorB = GetClassColor("party"..i)
				tankName = UnitName("party"..i)
			end
			unitTanking = GetTank("partypet"..i, "targettarget")
			if unitTanking == 1 then
				unitTankingColorR, unitTankingColorG, unitTankingColorB = GetClassColor("partypet"..i)
				tankName = UnitName("partypet"..i)
			end
			unitTanking = GetTank("pet", "target")
			if unitTanking == 1 then
				unitTankingColorR, unitTankingColorG, unitTankingColorB = GetClassColor("pet")
				tankName = UnitName("pet")
			end
		end
	end
	if status then -- show frame
		
		if self.db.profile.hidden == true and not threatbar:IsShown() then
			threatbar:Show()
		end
	end
	if status == 0
	then
		--icon:SetTexCoord(GetTexCoordsForRoleSmallCircle("DAMAGER"))
		font2:SetText(string.format("%d %%", threatpct ))
		threatbar:SetValue(threatpct)
		threatbar:SetStatusBarColor(0, 1, 0, 1)
		
		if tankName
		then
			--icon:SetTexCoord(GetTexCoordsForRoleSmallCircle("TANK"))
			--icon:Show()
			threatValuediff = ((unitThreatValue - playerThreatValue) / 100000 )
			font1:SetText(tankName)
			font1:SetTextColor(unitTankingColorR, unitTankingColorG, unitTankingColorB, 1)
			--BasicThreatBar:Print(unitTankingColorR, unitTankingColorG, unitTankingColorB) --debug message
			font2:SetText(string.format("%2.1fk | %d %%", threatValuediff, threatpct ))
			threatbar:SetValue(threatpct)
			if currenttarget then -- display temporary threat bar
				threatValuediff = ((unitThreatValue - currenttarget) / 100000 )
				tempthreatpct = floor((currenttarget / unitThreatValue) * 100)
				font1:SetText(tankName)
				font1:SetTextColor(unitTankingColorR, unitTankingColorG, unitTankingColorB, 1)
				font2:SetText(string.format("%2.1fk | %d %%", threatValuediff, tempthreatpct ))
				threatbar:SetValue(tempthreatpct)
				threatbar:SetStatusBarColor(.5, .5, 1, 1)
			end
		end
	elseif status == 1
	then
		--icon:SetTexCoord(GetTexCoordsForRoleSmallCircle("DAMAGER"))
		font2:SetText(string.format("%d %%", threatpct ))
		threatbar:SetValue(threatpct)
		threatbar:SetStatusBarColor(1, 1, 0, 1)
		
		if tankName
		then
			--icon:SetTexCoord(GetTexCoordsForRoleSmallCircle("TANK"))
			--icon:Show()
			threatValuediff = ((unitThreatValue - playerThreatValue) / 100000 )
			font1:SetText(tankName)
			font1:SetTextColor(unitTankingColorR, unitTankingColorG, unitTankingColorB, 1)
			--BasicThreatBar:Print(unitTankingColorR, unitTankingColorG, unitTankingColorB) --debug message
			font2:SetText(string.format("%2.1fk | %d %%", threatValuediff, threatpct ))
			threatbar:SetValue(threatpct)
			if currenttarget then -- display temporary threat bar
				threatValuediff = ((unitThreatValue - currenttarget) / 100000 )
				tempthreatpct = floor((currenttarget / unitThreatValue) * 100)
				font1:SetText(tankName)
				font1:SetTextColor(unitTankingColorR, unitTankingColorG, unitTankingColorB, 1)
				font2:SetText(string.format("%2.1fk | %d %%", threatValuediff, tempthreatpct ))
				threatbar:SetValue(tempthreatpct)
				threatbar:SetStatusBarColor(.5, .5, 1, 1)
			end
		end
	elseif status == 2
	then
		--icon:SetTexCoord(GetTexCoordsForRoleSmallCircle("DAMAGER"))
		font2:SetText("WEAK AGGRO!")
		threatbar:SetValue(threatpct)
		threatbar:SetStatusBarColor(1, .5, 0, 1)
		
		if highThreat ~= 0
		then
			--icon:SetTexCoord(GetTexCoordsForRoleSmallCircle("DAMAGER"))
			--icon:Show()
			threatValuediff = ((playerThreatValue - unitThreatValue) / 100000 )
			threatdiff = (threatpct - highThreat)
			font1:SetText(highUnit)
			font1:SetTextColor(highUnitColorR, highUnitColorG, highUnitColorB, 1)
			font2:SetText(string.format("%2.1fk | %s %%", threatValuediff, threatdiff ))
			threatbar:SetValue(threatdiff)
			threatbar:SetBackdropColor(1, .5, 0, .4)
			if currenttarget then -- display temporary threat bar
				threatValuediff = ((unitThreatValue - currenttarget) / 100000 )
				threatdiff = floor((currenttarget / unitThreatValue) * 100) - highThreat
				font1:SetText(highUnit)
				font1:SetTextColor(highUnitColorR, highUnitColorG, highUnitColorB, 1)
				font2:SetText(string.format("%2.1fk | %d %%", threatValuediff, threatdiff ))
				threatbar:SetValue(threatdiff)
				threatbar:SetStatusBarColor(.5, .5, 1, 1)
			end
		end	
	elseif status == 3
	then
		--icon:SetTexCoord(GetTexCoordsForRoleSmallCircle("DAMAGER"))
		font2:SetText("AGGRO!")
		threatbar:SetValue(threatpct)
		threatbar:SetStatusBarColor(1, 0, 0, 1)
		
		if highThreat ~= 0
		then
			--icon:SetTexCoord(GetTexCoordsForRoleSmallCircle("DAMAGER"))
			--icon:Show()
			threatValuediff = ((playerThreatValue - unitThreatValue) / 100000 )
			threatdiff = (threatpct - highThreat)
			font1:SetText(highUnit)
			font1:SetTextColor(highUnitColorR, highUnitColorG, highUnitColorB, 1)
			font2:SetText(string.format("%2.1fk | %s %%", threatValuediff, threatdiff ))
			threatbar:SetValue(threatdiff)
			threatbar:SetBackdropColor(1, 0, 0, .4)
			if currenttarget then -- display temporary threat bar
				threatValuediff = ((unitThreatValue - currenttarget) / 100000 )
				threatdiff = floor((currenttarget / unitThreatValue) * 100) - highThreat
				font1:SetText(highUnit)
				font1:SetTextColor(highUnitColorR, highUnitColorG, highUnitColorB, 1)
				font2:SetText(string.format("%2.1fk | %d %%", threatValuediff, threatdiff ))
				threatbar:SetValue(threatdiff)
				threatbar:SetStatusBarColor(.5, .5, 1, 1)
			end
		end
	end
end
		
function BasicThreatBar:COMBAT_LOG_EVENT_UNFILTERED(event, ...)
		local timestamp, eventtype, hideCaster, srcGUID, srcName, srcFlags, srcFlags2, dstGUID, dstName, dstFlags, dstFlags2 = ...
		local targetGUID = UnitGUID("target")
		local damage
		local playerGUID = UnitGUID("player")
		if srcGUID == playerGUID then
		if eventtype == "SPELL_AURA_APPLIED" then
			local spellID = select(12, ...)
			if spellID == 55342 or spellID == 586 --[[or spellID == 1038]] then
				--DEFAULT_CHAT_FRAME:AddMessage("Temp spell casted") --debug message
				fademiActive = true
				StoreThreat()		-- set temp threat to last known threat value
			elseif spellID == 32612 and fademiActive == true then -- Invisibility buff while Mirror Image is active
				wipe(tempthreat)
			end
		elseif eventtype == "SPELL_DAMAGE" or eventtype == "RANGE_DAMAGE" or eventtype == "SPELL_PERIODIC_DAMAGE" then
			if fademiActive == true then
			--DEFAULT_CHAT_FRAME:AddMessage("Detecting damage") --debug message
			damage = select(15, ...)
			
			end
		elseif eventtype == "SWING_DAMAGE" then
			if fademiActive == true then
			damage = select(12, ...)
			
			end
		elseif eventtype == "SPELL_AURA_REMOVED" then
			local spellID = select(12, ...)
			if spellID == 55342 or spellID == 586 --[[or spellID == 1038]] then
				--DEFAULT_CHAT_FRAME:AddMessage("Temp spell expired") --debug message
				wipe(tempthreat) -- clear table
				damage = nil
				fademiActive = nil
				currenttarget = nil
			end	
		end
		if damage then
			tempthreat[dstGUID] = (tempthreat[dstGUID] or 0) + damage * 100
			if targetGUID == dstGUID then
				currenttarget = tempthreat[dstGUID]
			end
		end
		--[[if fademiActive then
			UpdateDisplay()
		end]]
		end
		
end
	
function BasicThreatBar:PLAYER_TARGET_CHANGED(event)
		local targetGUID = UnitGUID("target")
		if fademiActive == true then
			local intable = tContains(tempthreat, targetGUID)
			if not intable then
				currenttarget = nil
				--DEFAULT_CHAT_FRAME:AddMessage("currentarget set to nil") -- debug message
			end
			for index,value in pairs(tempthreat) do 
				if targetGUID == index then
					currenttarget = value
					--DEFAULT_CHAT_FRAME:AddMessage(tostring(index).." : "..tostring(value)) -- debug message
				
				end
			
			end

		UpdateDisplay()
	else
		UpdateDisplay()
	end
end

function BasicThreatBar:UNIT_THREAT_SITUATION_UPDATE(event)
	UpdateDisplay()
end

function BasicThreatBar:UNIT_THREAT_LIST_UPDATE(event)
	UpdateDisplay()
end

function BasicThreatBar:PARTY_MEMBERS_CHANGED(event)
	UpdateDisplay()
end